@@ -20,6 +20,40 @@
 //! Lastly, [`xyz`] submodule provides functions for converting between linear
 //! sRGB and XYZ colour spaces as well as constants exposing the matrices used
 //! by those functions.
+//!
+//! # Features
+//!
+//! The crate defines two optional features:
+//!
+//! ### `no-fma`
+//!
+//! When enabled, the code will *not* use [`f32::mul_add`].  This may affect
+//! performance and precision of the code, however not using it results in more
+//! reproducible and well-defined floating point arithmetic.
+//!
+//! That is, while fused multiply-add improves precision of the calculation, it
+//! does that by not adhering to strict rules of floating point maths.
+//! According to them, an `a * b + c` expression should result in rounding after
+//! multiplication and then after addition.  Because the two operations are
+//! fused the middle rounding doesn’t happen.  Unless you care about such rules,
+//! you probably don’t want this feature enabled.
+//!
+//! Note that even if this feature is not enabled, that does not mean fused
+//! multiply-add instruction will be used.  Depending on processor the crate is
+//! built for, the code may choose a faster implementation of matrix
+//! multiplication which does not use fused multiply-add operation.  To make
+//! that happen, enable `prefer-fma`.
+//!
+//! ### `prefer-fma`
+//!
+//! When enabled, the code will use [a fused multiply-add
+//! operation](https://doc.rust-lang.org/std/primitive.f32.html#method.mul_add)
+//! whenever possible.  This will disable some potential performance
+//! optimisations which use SIMD instructions in favour of using fused
+//! multiply-add operation.  See notes about `no-fma` above for discussion of
+//! how FMA impacts precision of the calculations.
+//!
+//! Note that `no-fma` and `prefer-fma` are mutually exclusive
 
 pub mod gamma;
 pub mod rec709;
@@ -74,9 +108,7 @@ pub fn normalised_from_u8(encoded: [u8; 3]) -> [f32; 3] {
 #[doc(hidden)]
 pub fn u8_from_normalised(normalised: [f32; 3]) -> [u8; 3] {
     // Adding 0.5 is for rounding.
-    arr_map(normalised, |v| {
-        maths::mul_add(v.clamp(0.0, 1.0), 255.0, 0.5) as u8
-    })
+    arr_map(normalised, |v| v.clamp(0.0, 1.0).mul_add(255.0, 0.5) as u8)
 }
 
 
