@@ -23,7 +23,7 @@
 /// assert_eq!(1.0, srgb::rec709::decode_rec709_8bit(235));
 /// assert_eq!(1.0, srgb::rec709::decode_rec709_8bit(255));
 /// ```
-#[inline(always)]
+#[inline]
 pub fn decode_rec709_8bit(value: u8) -> f32 {
     (value.clamp(16, 235) - 16) as f32 / (235 - 16) as f32
 }
@@ -39,19 +39,19 @@ pub fn decode_rec709_8bit(value: u8) -> f32 {
 /// assert_eq!(1.0, srgb::rec709::decode_rec709_10bit(940));
 /// assert_eq!(1.0, srgb::rec709::decode_rec709_10bit(940));
 /// ```
-#[inline(always)]
+#[inline]
 pub fn decode_rec709_10bit(value: u16) -> f32 {
     (value.clamp(64, 940) - 64) as f32 / (940 - 64) as f32
 }
 
 /// Converts normalised value into 8-bit Rec.709 coding.
-#[inline(always)]
+#[inline]
 pub fn encode_rec709_8bit(value: f32) -> u8 {
     value.clamp(0.0, 1.0).mul_add((235 - 16) as f32, 16.5) as u8
 }
 
 /// Converts normalised value into 10-bit Rec.709 coding.
-#[inline(always)]
+#[inline]
 pub fn encode_rec709_10bit(value: f32) -> u16 {
     value.clamp(0.0, 1.0).mul_add((940 - 64) as f32, 64.5) as u16
 }
